@@ -26,10 +26,12 @@ __all__ = (
     "ListAlertsPaginatorName",
     "ListChannelsPaginatorName",
     "ListPlaybackConfigurationsPaginatorName",
+    "ListPrefetchSchedulesPaginatorName",
     "ListSourceLocationsPaginatorName",
     "ListVodSourcesPaginatorName",
     "MessageTypeType",
     "ModeType",
+    "OperatorType",
     "OriginManifestTypeType",
     "PlaybackModeType",
     "RelativePositionType",
@@ -46,10 +48,12 @@ GetChannelSchedulePaginatorName = Literal["get_channel_schedule"]
 ListAlertsPaginatorName = Literal["list_alerts"]
 ListChannelsPaginatorName = Literal["list_channels"]
 ListPlaybackConfigurationsPaginatorName = Literal["list_playback_configurations"]
+ListPrefetchSchedulesPaginatorName = Literal["list_prefetch_schedules"]
 ListSourceLocationsPaginatorName = Literal["list_source_locations"]
 ListVodSourcesPaginatorName = Literal["list_vod_sources"]
 MessageTypeType = Literal["SPLICE_INSERT"]
 ModeType = Literal["BEHIND_LIVE_EDGE", "OFF"]
+OperatorType = Literal["EQUALS"]
 OriginManifestTypeType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
 PlaybackModeType = Literal["LINEAR", "LOOP"]
 RelativePositionType = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
@@ -346,6 +350,7 @@ PaginatorName = Literal[
     "list_alerts",
     "list_channels",
     "list_playback_configurations",
+    "list_prefetch_schedules",
     "list_source_locations",
     "list_vod_sources",
 ]
