@@ -14,6 +14,7 @@ Usage::
         ListAlertsPaginator,
         ListChannelsPaginator,
         ListPlaybackConfigurationsPaginator,
+        ListPrefetchSchedulesPaginator,
         ListSourceLocationsPaginator,
         ListVodSourcesPaginator,
     )
@@ -24,6 +25,7 @@ Usage::
     list_alerts_paginator: ListAlertsPaginator = client.get_paginator("list_alerts")
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
+    list_prefetch_schedules_paginator: ListPrefetchSchedulesPaginator = client.get_paginator("list_prefetch_schedules")
     list_source_locations_paginator: ListSourceLocationsPaginator = client.get_paginator("list_source_locations")
     list_vod_sources_paginator: ListVodSourcesPaginator = client.get_paginator("list_vod_sources")
     ```
@@ -38,6 +40,7 @@ from .type_defs import (
     ListAlertsResponseTypeDef,
     ListChannelsResponseTypeDef,
     ListPlaybackConfigurationsResponseTypeDef,
+    ListPrefetchSchedulesResponseTypeDef,
     ListSourceLocationsResponseTypeDef,
     ListVodSourcesResponseTypeDef,
     PaginatorConfigTypeDef,
@@ -48,6 +51,7 @@ __all__ = (
     "ListAlertsPaginator",
     "ListChannelsPaginator",
     "ListPlaybackConfigurationsPaginator",
+    "ListPrefetchSchedulesPaginator",
     "ListSourceLocationsPaginator",
     "ListVodSourcesPaginator",
 )
@@ -65,7 +69,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class GetChannelSchedulePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
     """
 
@@ -77,14 +81,14 @@ class GetChannelSchedulePaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetChannelScheduleResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
 
 class ListAlertsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listalertspaginator)
     """
 
@@ -92,14 +96,14 @@ class ListAlertsPaginator(Boto3Paginator):
         self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAlertsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listalertspaginator)
         """
 
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
     """
 
@@ -107,14 +111,14 @@ class ListChannelsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListChannelsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
 
 class ListPlaybackConfigurationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
     """
 
@@ -122,14 +126,33 @@ class ListPlaybackConfigurationsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPlaybackConfigurationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
 
+class ListPrefetchSchedulesPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrefetchSchedules)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listprefetchschedulespaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        PlaybackConfigurationName: str,
+        StreamId: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPrefetchSchedulesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrefetchSchedules.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listprefetchschedulespaginator)
+        """
+
+
 class ListSourceLocationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
     """
 
@@ -137,14 +160,14 @@ class ListSourceLocationsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSourceLocationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
 
 class ListVodSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
     """
 
@@ -152,6 +175,6 @@ class ListVodSourcesPaginator(Boto3Paginator):
         self, *, SourceLocationName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListVodSourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
